# Generated by Django 3.2.9 on 2022-04-07 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_slm', '0002_alter_softwareproduct_manufacturer'),
    ]

    operations = [
        migrations.AlterField(
            model_name='softwareproduct',
            name='created',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name='softwareproduct',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='softwareproductinstallation',
            name='created',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name='softwareproductinstallation',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='softwareproductversion',
            name='created',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name='softwareproductversion',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False),
        ),
    ]
