from .software_license import (
    SoftwareLicenseListView,
    SoftwareLicenseView,
    SoftwareLicenseEditView,
    SoftwareLicenseDeleteView,
    SoftwareLicenseBulkImportView,
    SoftwareLicenseBulkEditView,
    SoftwareLicenseBulkDeleteView,
)
from .software_product import (
    SoftwareProductListView,
    SoftwareProductView,
    SoftwareProductEditView,
    SoftwareProductDeleteView,
    SoftwareProductBulkImportView,
    SoftwareProductBulkEditView,
    SoftwareProductBulkDeleteView,
)
from .software_product_installation import (
    SoftwareProductInstallationListView,
    SoftwareProductInstallationView,
    SoftwareProductInstallationEditView,
    SoftwareProductInstallationDeleteView,
    SoftwareProductInstallationBulkImportView,
    SoftwareProductInstallationBulkEditView,
    SoftwareProductInstallationBulkDeleteView,
)
from .software_product_version import (
    SoftwareProductVersionListView,
    SoftwareProductVersionView,
    SoftwareProductVersionEditView,
    SoftwareProductVersionDeleteView,
    SoftwareProductVersionBulkImportView,
    SoftwareProductVersionBulkEditView,
    SoftwareProductVersionBulkDeleteView,
)
