# Generated by Django 4.2.5 on 2023-09-22 00:34

from django.db import migrations
import netbox_slm.models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_slm', '0005_add_software_license'),
    ]

    operations = [
        migrations.AddField(
            model_name='softwarelicense',
            name='stored_location_url',
            field=netbox_slm.models.LaxURLField(blank=True, max_length=1024, null=True),
        ),
    ]
