# Generated by Django 3.2.9 on 2022-01-24 08:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0133_port_colors'),
        ('netbox_slm', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='softwareproduct',
            name='manufacturer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='software_products', to='dcim.manufacturer'),
        ),
    ]
