{% extends 'generic/object.html' %}
{% load buttons %}
{% load static %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row my-3">
	<div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">
                Software Product
            </h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">Name</th>
                        <td>{{ object.name }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Description</th>
                        <td>{{ object.description }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Manufacturer</th>
                        <td>{{ object.manufacturer }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Versions</th>
                        <td>
                        {% for version in object.softwareproduct_versions.all %}
                            <a href="{% url 'plugins:netbox_slm:softwareproductversion' pk=version.pk %}">
                                <span class="badge" style="color: #ffffff; background-color: #9e9e9e">{{ version }}</span>
                            </a>
                        {% empty %}
                            n/a
                        {% endfor %}
                        </td>
                    </tr>
                </table>
            </div>
        </div>
        {% include 'inc/panels/custom_fields.html' %}
        {% include 'inc/panels/tags.html' %}
        {% include 'inc/panels/comments.html' %}
        {% plugin_left_page object %}
    </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}
